import config from '../../config'
import apiClient from './apiClient.js'
let ratelogDomain = process.env.NODE_ENV === 'production' ? config.build.env.rate_domain : config.dev.env.rate_domain
let ratelog2ndsrcDomain = process.env.NODE_ENV === 'production' ? config.build.env.ratelog2ndsrc_domain : config.dev.env.rate_domain
let basicDomain = process.env.NODE_ENV === 'production' ? config.build.env.base_domain : config.dev.env.base_domain

function queryAllHotels (success, error) {
  apiClient('GET', basicDomain + '/hotels', {
  	onlyActive: 1
  }, function (data) {
    if (success) {
      success(data)
    }
  }, function (errdata) {
    if (error) {
      error(errdata)
    }
  })

}

function queryPriceSetting (dateunix, success, error) {
  apiClient('GET', ratelogDomain + '/hotels/price/setting', {
  	date: dateunix
  }, function (data) {
    if (success) {
      success(data)
    }
  }, function (errdata) {
    if (error) {
      error(errdata)
    }
  })
}

function settingPrice(hotelid,paramData,success,error){
	apiClient('POST', ratelogDomain + '/hotel/'+hotelid+'/price/setting', paramData, function (data) {
    if (success) {
      success(data)
    }
  }, function (errdata) {
    if (error) {
      error(errdata)
    }
  })
}

function hotelClassicRooms(hotelid,success,error){
	apiClient('GET', ratelogDomain + '/hotel/'+hotelid+'/classic/rooms',{status: 0}, function (data) {
    if (success) {
      success(data)
    }
  }, function (errdata) {
    if (error) {
      error(errdata)
    }
  })
}
function competitorsOfHotel(hotelid,type,success,error){
	apiClient('GET', (type==0?ratelogDomain:ratelog2ndsrcDomain) + '/hotel/'+hotelid+'/competitors',{all: 1,status: 1}, function (data) {
    if (success) {
      success(data)
    }
  }, function (errdata) {
    if (error) {
      error(errdata)
    }
  })
}

function latestPriceOfRoomsForHotels(hotelid,dateunix,ids,type,success,error){
	apiClient('GET',(type==0?ratelogDomain:ratelog2ndsrcDomain) + '/hotel/'+hotelid+'/rooms/price/latest',{
		  date: dateunix,
			configIds: ids
	}, function (data) {
    if (success) {
      success(data)
    }
  }, function (errdata) {
    if (error) {
      error(errdata)
    }
  })
}
/**
 * 
 * @param {Object} hotelId  酒店编号
 * @param {Object} start 开始索引
 * @param {Object} end  结束索引
 * @param {Object} type 类型 0:priceline 1:hotels
 * @param {Object} success 成功回调
 * @param {Object} error  失败回调
 */
function roomsSoldOutStatusListOfHotels(hotelId,start,end,type,success,error){
	apiClient('GET',(type==0?ratelogDomain:ratelog2ndsrcDomain) + '/hotel/configs/roomsSoldOutStatus',{
		"hotelId":hotelId,
		"start": start,
		"end":end
	}, function (data) {
    if (success) {
      success(data)
    }
  }, function (errdata) {
    if (error) {
      error(errdata)
    }
  })
}

/**
 * 
 * @param {Object} configId 配置编号
 * @param {Object} date 时间unix
 * @param {Object} page 页码
 * @param {Object} type 类型 0:priceline 1:hotels
 * @param {Object} success 成功回调方法
 * @param {Object} error  失败回调方法
 */
function roomsPriceListOfHotel(configId,date,page,type,success,error){
	apiClient('GET',(type==0?ratelogDomain:ratelog2ndsrcDomain) + '/hotel/config/'+configId+'/rooms/priceInfos',{
		"date":date,
		"page": page,
		"size":10
	}, function (data) {
    if (success) {
      success(data)
    }
  }, function (errdata) {
    if (error) {
      error(errdata)
    }
  })
}
/**
 * 
 * @param {Object} configId 酒店编号
 * @param {Object} classicRoomId 房间编号
 * @param {Object} date  时间
 * @param {Object} page  当前页码
 * @param {Object} type  类型0:priceline 数据源 1:hotels 数据源
 * @param {Object} success 成功回调方法
 * @param {Object} error 失败回调方法
 */
function roomsPriceHistoryListOfHotel(configId,classicRoomId,date,page,type,success,error){
	apiClient('GET',(type==0?ratelogDomain:ratelog2ndsrcDomain) + '/hotelConfig/'+configId+'/room/'+classicRoomId+'/price/history',{
		"date":date,
		"page": page,
		"size":10
	}, function (data) {
    if (success) {
      success(data)
    }
  }, function (errdata) {
    if (error) {
      error(errdata)
    }
  })
}

/**
 *  查询出freestyle记录
 * @param {Object} type 访问后台类型
 * @param {Object} hotelId 酒店类型
 * @param {Object} startDate 开始时间
 * @param {Object} endDate 结束时间
 * @param {Object} success  成功回调
 * @param {Object} error  失败回调
 */

function roomsPrice4FreeStyle(type,hotelId,startDate,endDate,success,error){
	apiClient('GET',(type==0?ratelogDomain:ratelog2ndsrcDomain) + '/hotel/'+hotelId+'/rooms/price/freestyle',{
		"startDate":startDate,
		"endDate": endDate
	}, function (data) {
    if (success) {
      success(data)
    }
  }, function (errdata) {
    if (error) {
      error(errdata)
    }
  })
}

export {
	queryAllHotels,
	queryPriceSetting,
	settingPrice,
	competitorsOfHotel,
	latestPriceOfRoomsForHotels,
	roomsSoldOutStatusListOfHotels,
	roomsPriceListOfHotel,
	roomsPriceHistoryListOfHotel,
	roomsPrice4FreeStyle,
	hotelClassicRooms
}
